<?php
class ModelExtensionModuleiSenseLabsGdpr extends Model {  
    
    public function initDb() {
        // Create table for GDPR Requests
		$this->db->query("CREATE TABLE IF NOT EXISTS `" . DB_PREFIX . "isense_gdpr_requests` (
            `request_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
            `customer_id` int(10)  NOT NULL DEFAULT '0',
            `email` varchar(255) NOT NULL,
            `type` varchar(255) NOT NULL,
            `user_agent` varchar(255) NOT NULL,
            `accept_language` varchar(100) NOT NULL,
			`client_ip` varchar(100) NOT NULL, 
			`server_ip` varchar(100) NOT NULL,
            `request_added` datetime NOT NULL,
            PRIMARY KEY (`request_id`)
        ) CHARACTER SET utf8 COLLATE utf8_general_ci");
		
		// Create table for GDPR Policy Acceptances
		$this->db->query("CREATE TABLE IF NOT EXISTS `" . DB_PREFIX . "isense_gdpr_policy_acceptances` (
            `acceptance_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
            `email` varchar(255) NOT NULL,
            `policy_id` varchar(255) NOT NULL,
            `name` varchar(255) NOT NULL,
            `content` longtext NOT NULL,
			`user_agent` varchar(255) NOT NULL,
            `accept_language` varchar(100) NOT NULL,
			`client_ip` varchar(100) NOT NULL, 
            `date_added` datetime NOT NULL,
            PRIMARY KEY (`acceptance_id`)
        ) CHARACTER SET utf8 COLLATE utf8_general_ci");
		
		// Create table for GDPR Submissions
		$this->db->query("CREATE TABLE IF NOT EXISTS `" . DB_PREFIX . "isense_gdpr_submissions` (
            `submission_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
            `email` varchar(255) NOT NULL,
			`type` varchar(255) NOT NULL,
            `hash` varchar(255) NOT NULL,
            `date_added` datetime NOT NULL,
            PRIMARY KEY (`submission_id`)
        ) CHARACTER SET utf8 COLLATE utf8_general_ci");

        // Create table for GDPR Optins
        $this->db->query("CREATE TABLE IF NOT EXISTS `" . DB_PREFIX . "isense_gdpr_optins` (
            `optin_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
            `email` varchar(255) NOT NULL,
            `policy_id` varchar(255) NOT NULL,
            `type` varchar(100) NOT NULL,
            `action` varchar(100) NOT NULL,
            `user_agent` varchar(255) NOT NULL,
            `accept_language` varchar(100) NOT NULL,
            `client_ip` varchar(100) NOT NULL, 
            `date_added` datetime NOT NULL,
            PRIMARY KEY (`optin_id`)
        ) CHARACTER SET utf8 COLLATE utf8_general_ci");
    }
	
	// Requests - Begin
	private function getRequestFilterData($data = array()) {
		$query = '';
		
		if (!empty($data['request_id'])) {
            $query .= " AND `request_id` = '" . (int)$this->db->escape($data['request_id']) . "'";
        }
		
        if (!empty($data['email'])) {
            $query .= " AND `email` LIKE '%" . $this->db->escape($data['email']) . "%'";
        }
		
		if (!empty($data['type'])) {
            $query .= " AND `type` = '" . $this->db->escape($data['type']) . "'";
        }
		
		if (!empty($data['user_agent'])) {
            $query .= " AND `user_agent` LIKE '%" . $this->db->escape($data['user_agent']) . "%'";
        }
		
		if (!empty($data['accept_language'])) {
            $query .= " AND `accept_language` LIKE '%" . $this->db->escape($data['accept_language']) . "%'";
        }
		
		if (!empty($data['client_ip'])) {
            $query .= " AND `client_ip` = '" . $this->db->escape($data['client_ip']) . "'";
        }
		
		if (!empty($data['server_ip'])) {
            $query .= " AND `server_ip` = '" . $this->db->escape($data['server_ip']) . "'";
        }
        
        if (!empty($data['date_start'])) {
            $query .= " AND `request_added` >= '" . $this->db->escape($data['date_start']) . " 00:00:00'";
        }
        
        if (!empty($data['date_end'])) {
            $query .= " AND `request_added` <= '" . $this->db->escape($data['date_end']) . " 23:59:59'";
        }
		
		return $query;
	}
	
	public function getRequests($data = array(), $page = 1, $limit = 20) {
		$query = "SELECT * FROM `" . DB_PREFIX . "isense_gdpr_requests` WHERE 1=1 ";

        $query .= $this->getRequestFilterData($data);
        
        if ($page) {
			$start = ($page - 1) * $limit;
		}
        
        $query .= "ORDER BY `request_id` DESC LIMIT ".$start.", ".$limit;
        
        $query = $this->db->query($query);

        return $query->rows;
	}
	
	public function getTotalRequests($data = array()) {
		$query = "SELECT COUNT(*) as `count`  FROM `" . DB_PREFIX . "isense_gdpr_requests` WHERE 1=1";
        
       	$query .= $this->getRequestFilterData($data);
		
		$query = $this->db->query($query);
        
		return $query->row['count']; 
	}
	// Requests - End
	
	
	// Policy Acceptances - Begin
	private function getPolicyAcceptancesFilterData($data = array()) {
		$query = '';
		
		if (!empty($data['acceptance_id'])) {
            $query .= " AND `acceptance_id` = '" . (int)$this->db->escape($data['acceptance_id']) . "'";
        }
		
        if (!empty($data['email'])) {
            $query .= " AND `email` LIKE '%" . $this->db->escape($data['email']) . "%'";
        }
		
		if (!empty($data['name'])) {
            $query .= " AND `name` LIKE '%" . $this->db->escape($data['name']) . "%'";
        }

        if (!empty($data['date_start'])) {
            $query .= " AND `date_added` >= '" . $this->db->escape($data['date_start']) . " 00:00:00'";
        }
        
        if (!empty($data['date_end'])) {
            $query .= " AND `date_added` <= '" . $this->db->escape($data['date_end']) . " 23:59:59'";
        }
		
		return $query;
	}
	
	public function getPolicyAcceptances($data = array(), $page = 1, $limit = 20) {
		$query = "SELECT * FROM `" . DB_PREFIX . "isense_gdpr_policy_acceptances` WHERE 1=1 ";

        $query .= $this->getPolicyAcceptancesFilterData($data);
        
        if ($page) {
			$start = ($page - 1) * $limit;
		}
        
        $query .= "ORDER BY `acceptance_id` DESC LIMIT ".$start.", ".$limit;
        
        $query = $this->db->query($query);

        return $query->rows;
	}
	
	public function getTotalPolicyAcceptances($data = array()) {
		$query = "SELECT COUNT(*) as `count`  FROM `" . DB_PREFIX . "isense_gdpr_policy_acceptances` WHERE 1=1";
        
       	$query .= $this->getPolicyAcceptancesFilterData($data);
		
		$query = $this->db->query($query);
        
		return $query->row['count']; 
	}
	
	public function getPolicyAcceptanceContent($acceptance_id = 0) {
		if ($acceptance_id != 0) {
			$query = $this->db->query("SELECT `content` FROM `" . DB_PREFIX . "isense_gdpr_policy_acceptances` WHERE `acceptance_id`='" . (int)$this->db->escape($acceptance_id) . "' LIMIT 1")->row;
			if (!empty($query['content'])) {
				return html_entity_decode($query['content']);
			} else {
				return '';
			}
		} else {
			return '';
		}
	}
	// Policy Acceptances - End

    // Opt-ins - Start

    private function getOptinsFilterData($data = array()) {
        $query = '';
        
        if (!empty($data['optin_id'])) {
            $query .= " AND `optin_id` = '" . (int)$this->db->escape($data['optin_id']) . "'";
        }
        
        if (!empty($data['email'])) {
            $query .= " AND `email` LIKE '%" . $this->db->escape($data['email']) . "%'";
        }

        if (!empty($data['type'])) {
            $query .= " AND `type` LIKE '%" . $this->db->escape($data['type']) . "%'";
        }

        if (!empty($data['action']) && ($data['action']!='-')) {
            $query .= " AND `action` LIKE '%" . $this->db->escape($data['action']) . "%'";
        }

        if (!empty($data['date_start'])) {
            $query .= " AND `date_added` >= '" . $this->db->escape($data['date_start']) . " 00:00:00'";
        }
        
        if (!empty($data['date_end'])) {
            $query .= " AND `date_added` <= '" . $this->db->escape($data['date_end']) . " 23:59:59'";
        }
        
        return $query;
    }
    
    public function getOptins($data = array(), $page = 1, $limit = 20) {
        $query = "SELECT * FROM `" . DB_PREFIX . "isense_gdpr_optins` WHERE 1=1 ";

        $query .= $this->getOptinsFilterData($data);
        
        if ($page) {
            $start = ($page - 1) * $limit;
        }
        
        $query .= "ORDER BY `optin_id` DESC LIMIT ".$start.", ".$limit;
        
        $query = $this->db->query($query);

        return $query->rows;
    }
    
    public function getTotalOptins($data = array()) {
        $query = "SELECT COUNT(*) as `count`  FROM `" . DB_PREFIX . "isense_gdpr_optins` WHERE 1=1";
        
        $query .= $this->getOptinsFilterData($data);
        
        $query = $this->db->query($query);
        
        return $query->row['count']; 
    }

    // Opt-ins - End
}